@@ -1,7 +1,6 @@
-# coding: utf-8
 from django.contrib import admin
 
-from models import FormType
+from .models import FormType
 
 
 class FormTypeAdmin(admin.ModelAdmin):
