@@ -1,7 +1,6 @@
-# coding: utf-8
 from django.contrib import admin
 
-from models import FeedType
+from .models import FeedType
 
 
 class FeedTypeAdmin(admin.ModelAdmin):
