@@ -1,4 +1,3 @@
-# coding: utf-8
 from django.db import models
 from django.db.models.signals import pre_delete
 from django.dispatch.dispatcher import receiver
@@ -12,7 +11,7 @@ class Folder(models.Model):
 
 
 class File(models.Model):
-    folder = models.ForeignKey(Folder, related_name='files')
+    folder = models.ForeignKey(Folder, related_name='files', on_delete=models.CASCADE)
     path = models.FileField(upload_to='uploads/%Y/%m/%d', max_length=300)
     date_created = models.DateTimeField(auto_now_add=True)
 
