@@ -1,12 +1,10 @@
-# coding: utf-8
-from django.conf.urls import url
-
 from dartcms import get_model
 from dartcms.utils.config import DartCMSConfig
-from dartcms.views import DeleteObjectView, GridView, UpdateObjectView
 
 from .forms import OrderDatailForm
 
+app_name = 'order_details'
+
 Order = get_model('shop', 'OrderDetail')
 
 config = DartCMSConfig({
@@ -26,8 +24,4 @@ config = DartCMSConfig({
     }
 })
 
-urlpatterns = [
-    url(r'^$', GridView.as_view(**config.grid), name='index'),
-    url(r'^update/(?P<pk>\d+)/$', UpdateObjectView.as_view(**config.form), name='update'),
-    url(r'^delete/(?P<pk>\d+)/$', DeleteObjectView.as_view(**config.base), name='delete'),
-]
+urlpatterns = config.get_urls(exclude=['insert'])
