@@ -1,12 +1,10 @@
-# coding: utf-8
+from dartcms.utils.loading import get_model
 from django.forms import HiddenInput
 from django.utils.translation import ugettext_lazy as _
-
-from dartcms.utils.loading import get_model
-from form_utils.forms import BetterModelForm
+from django.forms import ModelForm
 
 
-class ProductSectionForm(BetterModelForm):
+class ProductSectionForm(ModelForm):
     class Meta:
         model = get_model('shop', 'ProductSection')
         exclude = ['catalog', 'sort']
