@@ -1,32 +1,40 @@
-# -*- coding: utf-8 -*-
-from django.conf.urls import url
-from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
-
 from dartcms.utils.config import DartCMSConfig
 from dartcms.views import DeleteObjectView, GridView
-from forms import UserForm
-from views import ChangePasswordView, CMSUserInsertView, CMSUserUpdateView
+from django.conf.urls import url
+from django.utils.translation import ugettext_lazy as _
+
+from .forms import UserForm
+from .models import CMSUser
+from .views import ChangePasswordView, CMSUserInsertView, CMSUserUpdateView
+
+app_name = "users"
 
 config = DartCMSConfig({
-    'model': User,
+    'model': CMSUser,
     'grid': {
         'grid_columns': [
-            {'field': 'username', 'width': '60%'},
+            {'field': CMSUser.USERNAME_FIELD, 'width': '60%'},
             {'field': 'last_login', 'width': '20%'},
             {'field': 'is_staff', 'width': '10%'},
             {'field': 'is_active', 'width': '10%'},
         ],
-        'additional_grid_actions': [
-            {'url': 'change-password', 'label': _('Change Password'), 'icon': 'edit'}
+        'search': [
+            CMSUser.USERNAME_FIELD, 'email'
         ],
+        'additional_grid_actions': [
+            {
+                'url': 'change-password', 'label': _('Change Password'), 'icon': 'edit',
+                'required_permissions': '__all__', 'kwarg_name': 'pk'
+            }
+        ],
+        'model_properties': [CMSUser.USERNAME_FIELD]
     },
     'form': {
         'form_class': UserForm
     }
 })
 
-urlpatterns = [
+urlpatterns = config.get_urls(exclude=['addition', 'insert', 'update', 'delete']) + [
     url(r'^$', GridView.as_view(**config.grid), name='index'),
     url(r'^insert/$', CMSUserInsertView.as_view(**config.form), name='insert'),
     url(r'^update/(?P<pk>\d+)/$', CMSUserUpdateView.as_view(**config.form), name='update'),
